==> kde-workspace-4.9.80.tar.xz: kde-workspace-4.9.80/appmenu/menubutton.cpp <==
/*
  This file is part of the KDE project.

  Copyright (c) 2011 Lionel Chauvin <megabigbug@yahoo.fr>
  Copyright (c) 2011,2012 Cédric Bellegarde <gnumdk@gmail.com>

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.
*/

#include "menubutton.h"

void MenuButton::setHovered(bool hovered)
{
    if (hovered) {
        hoverEnterEvent(0);
    } else {
        hoverLeaveEvent(0);
    }
}

void MenuButton::hoverEnterEvent(QGraphicsSceneHoverEvent *e)
{
    m_enterEvent = true;
    Plasma::ToolButton::hoverEnterEvent(e);
}

void MenuButton::hoverLeaveEvent(QGraphicsSceneHoverEvent *e)
{
    if (m_enterEvent) {
        m_enterEvent = false;
        Plasma::ToolButton::hoverLeaveEvent(e);
    }
}

#include "menubutton.moc"

==> kde-workspace-4.9.90.tar.xz: kde-workspace-4.9.90/appmenu/menubutton.cpp <==
/*
  This file is part of the KDE project.

  Copyright (c) 2011 Lionel Chauvin <megabigbug@yahoo.fr>
  Copyright (c) 2011,2012 Cédric Bellegarde <gnumdk@gmail.com>

  Permission is hereby granted, free of charge, to any person obtaining a
  copy of this software and associated documentation files (the "Software"),
  to deal in the Software without restriction, including without limitation
  the rights to use, copy, modify, merge, publish, distribute, sublicense,
  and/or sell copies of the Software, and to permit persons to whom the
  Software is furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.
*/

#include "menubutton.h"
#include <QAction>

MenuButton::MenuButton(QGraphicsWidget *parent):
    Plasma::ToolButton(parent),
    m_enterEvent(false)
{
}

QAction* MenuButton::action()
{
    QAction *action = Plasma::ToolButton::action();
    if (action) {
        if (action->menu()) {
            return action;
        }
    }
    return 0;
}

void MenuButton::setHovered(bool hovered)
{
    if (hovered) {
        hoverEnterEvent(0);
    } else {
        hoverLeaveEvent(0);
    }
}

QSizeF MenuButton::sizeHint(Qt::SizeHint which, const QSizeF& constraint) const
{
    QSizeF sh = Plasma::ToolButton::sizeHint(which, constraint);
    if (which == Qt::MinimumSize || which == Qt::PreferredSize) {
        sh.setHeight(nativeWidget()->fontMetrics().height() + bottomMargin());
    }
    return sh;
}

qreal MenuButton::bottomMargin() const
{
    qreal left, right, top, bottom;
    getContentsMargins(&left, &right, &top, &bottom);
    return bottom;
}

void MenuButton::hoverEnterEvent(QGraphicsSceneHoverEvent *e)
{
    m_enterEvent = true;
    Plasma::ToolButton::hoverEnterEvent(e);
}

void MenuButton::hoverLeaveEvent(QGraphicsSceneHoverEvent *e)
{
    if (m_enterEvent) {
        m_enterEvent = false;
        Plasma::ToolButton::hoverLeaveEvent(e);
    }
}

#include "menubutton.moc"
